---
title: <span class="badge object-type-scalar"></span> Gibibytes
---
# <span class="badge object-type-scalar"></span> Gibibytes

Data: gibibytes

## Definition

```python
# Data: gibibytes
Gibibytes: typing.Literal["gbytes"] = "gbytes"
```
